==> ckeditor5-cloud-services-10.0.0.tgz: package/README.md <==
CKEditor 5 Cloud Services
=========================

[![Join the chat at https://gitter.im/ckeditor/ckeditor5](https://badges.gitter.im/ckeditor/ckeditor5.svg)](https://gitter.im/ckeditor/ckeditor5?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm version](https://badge.fury.io/js/%40ckeditor%2Fckeditor5-cloud-services.svg)](https://www.npmjs.com/package/@ckeditor/ckeditor5-cloud-services)
[![Build Status](https://travis-ci.org/ckeditor/ckeditor5-cloud-services.svg?branch=master)](https://travis-ci.org/ckeditor/ckeditor5-cloud-services)
[![BrowserStack Status](https://www.browserstack.com/automate/badge.svg?badge_key=d3hvenZqQVZERFQ5d09FWXdyT0ozVXhLaVltRFRjTTUyZGpvQWNmWVhUUT0tLUZqNlJ1YWRUd0RvdEVOaEptM1B2Q0E9PQ==--c9d3dee40b9b4471ff3fb516d9ecf8d09292c7e0)](https://www.browserstack.com/automate/public-build/d3hvenZqQVZERFQ5d09FWXdyT0ozVXhLaVltRFRjTTUyZGpvQWNmWVhUUT0tLUZqNlJ1YWRUd0RvdEVOaEptM1B2Q0E9PQ==--c9d3dee40b9b4471ff3fb516d9ecf8d09292c7e0)
[![Coverage Status](https://coveralls.io/repos/github/ckeditor/ckeditor5-cloud-services/badge.svg?branch=master)](https://coveralls.io/github/ckeditor/ckeditor5-cloud-services?branch=master)
<br>
[![Dependency Status](https://david-dm.org/ckeditor/ckeditor5-cloud-services/status.svg)](https://david-dm.org/ckeditor/ckeditor5-cloud-services)
[![devDependency Status](https://david-dm.org/ckeditor/ckeditor5-cloud-services/dev-status.svg)](https://david-dm.org/ckeditor/ckeditor5-cloud-services?type=dev)

CKEditor 5's [Cloud Services](https://ckeditor.com/ckeditor-cloud-services/) integration layer, which handles `config.cloudServices` and tokens.

## Documentation

See the [`@ckeditor/ckeditor5-cloud-services` package](https://docs.ckeditor.com/ckeditor5/latest/api/cloudservices.html) page in [CKEditor 5 documentation](https://docs.ckeditor.com/ckeditor5/latest/).

## License

Licensed under the terms of [GNU General Public License Version 2 or later](http://www.gnu.org/licenses/gpl.html). For full details about the license, please check the `LICENSE.md` file.

==> ckeditor5-cloud-services-10.0.2.tgz: package/README.md <==
CKEditor 5 Cloud Services
=========================

[![Join the chat at https://gitter.im/ckeditor/ckeditor5](https://badges.gitter.im/ckeditor/ckeditor5.svg)](https://gitter.im/ckeditor/ckeditor5?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm version](https://badge.fury.io/js/%40ckeditor%2Fckeditor5-cloud-services.svg)](https://www.npmjs.com/package/@ckeditor/ckeditor5-cloud-services)
[![Build Status](https://travis-ci.org/ckeditor/ckeditor5-cloud-services.svg?branch=master)](https://travis-ci.org/ckeditor/ckeditor5-cloud-services)
[![BrowserStack Status](https://automate.browserstack.com/automate/badge.svg?badge_key=d3hvenZqQVZERFQ5d09FWXdyT0ozVXhLaVltRFRjTTUyZGpvQWNmWVhUUT0tLUZqNlJ1YWRUd0RvdEVOaEptM1B2Q0E9PQ==--c9d3dee40b9b4471ff3fb516d9ecf8d09292c7e0)](https://automate.browserstack.com/public-build/d3hvenZqQVZERFQ5d09FWXdyT0ozVXhLaVltRFRjTTUyZGpvQWNmWVhUUT0tLUZqNlJ1YWRUd0RvdEVOaEptM1B2Q0E9PQ==--c9d3dee40b9b4471ff3fb516d9ecf8d09292c7e0)
[![Coverage Status](https://coveralls.io/repos/github/ckeditor/ckeditor5-cloud-services/badge.svg?branch=master)](https://coveralls.io/github/ckeditor/ckeditor5-cloud-services?branch=master)
<br>
[![Dependency Status](https://david-dm.org/ckeditor/ckeditor5-cloud-services/status.svg)](https://david-dm.org/ckeditor/ckeditor5-cloud-services)
[![devDependency Status](https://david-dm.org/ckeditor/ckeditor5-cloud-services/dev-status.svg)](https://david-dm.org/ckeditor/ckeditor5-cloud-services?type=dev)

CKEditor 5's [Cloud Services](https://ckeditor.com/ckeditor-cloud-services/) integration layer, which handles `config.cloudServices` and tokens.

## Documentation

See the [`@ckeditor/ckeditor5-cloud-services` package](https://docs.ckeditor.com/ckeditor5/latest/api/cloudservices.html) page in [CKEditor 5 documentation](https://docs.ckeditor.com/ckeditor5/latest/).

## License

Licensed under the terms of [GNU General Public License Version 2 or later](http://www.gnu.org/licenses/gpl.html). For full details about the license, please check the `LICENSE.md` file.
